@@ -19,18 +19,20 @@ from __future__ import absolute_import, division, print_function, with_statement
 
 from schematics.models import Model
 from schematics.types import StringType
+from schematics.types import IntType
 
 from tornado.ioloop import IOLoop
 from tornado.testing import AsyncHTTPTestCase
-from tornado.web import Application
 
 import supercell.api as s
 from supercell.api import (RequestHandler, provides, consumes)
+from supercell.api.environment import Environment
 
 
 class SimpleMessage(Model):
     doc_id = StringType()
     message = StringType()
+    number = IntType()
 
 
 @provides(s.MediaType.ApplicationJson)
@@ -68,12 +70,11 @@ class MyEchoHandler(RequestHandler):
 class TestSimpleRequestHandler(AsyncHTTPTestCase):
 
     def get_app(self):
-        app = Application([
-            ('/test', MyHandler),
-            ('/test_default', MyHandlerWithDefault),
-            ('/test_post', MyEchoHandler),
-        ])
-        return app
+        env = Environment()
+        env.add_handler('/test', MyHandler)
+        env.add_handler('/test_default', MyHandlerWithDefault)
+        env.add_handler('/test_post', MyEchoHandler)
+        return env.get_application()
 
     def get_new_ioloop(self):
         return IOLoop.instance()
@@ -102,6 +103,47 @@ class TestSimpleRequestHandler(AsyncHTTPTestCase):
     def test_post_handler(self):
         response = self.fetch('/test_post', method='POST',
                               headers={'Content-Type': s.MediaType.ApplicationJson},
-                              body='{"message": "Simple message"}')
+                              body='{"message": "Simple message", "number": 1}')
         self.assertEqual(response.code, 201)
         self.assertEqual(response.body, '{"docid": 123, "ok": true}')
+
+    def test_post_handler_with_wrong_value_type(self):
+        response = self.fetch('/test_post', method='POST',
+                              headers={'Content-Type': s.MediaType.ApplicationJson},
+                              body='{"number": "one"}')
+        self.assertEqual(response.code, 400)
+
+
+@provides(s.MediaType.ApplicationJson, default=True)
+class EncodingTestingHandler(s.RequestHandler):
+
+    @s.async
+    def get(self, *args, **kwargs):
+        r = SimpleMessage(doc_id='test123',
+                          message='args=%s; kwargs=%s' % (args, kwargs))
+        raise s.Return(r)
+
+
+class TestUrlEncoding(AsyncHTTPTestCase):
+
+    def get_app(self):
+        env = Environment()
+        env.add_handler('/testencoding/(.*)', EncodingTestingHandler)
+        return env.get_application()
+
+    def get_new_ioloop(self):
+        return IOLoop.instance()
+
+    def test_latinone_handler(self):
+        response = self.fetch('/testencoding/alfredo-p%e9rez-rubalcaba')
+        self.assertEqual(200, response.code)
+        self.assertEqual('{"message": "args=(u\'alfredo-p\\\\xe9rez-' + \
+                         'rubalcaba\',); kwargs={}", "doc_id": "test123"}',
+                         response.body)
+
+    def test_utfeight_handler(self):
+        response = self.fetch('/testencoding/alfredo-p%C3%A9rez-rubalcaba')
+        self.assertEqual(200, response.code)
+        self.assertEqual('{"message": "args=(u\'alfredo-p\\\\xe9rez-' + \
+                         'rubalcaba\',); kwargs={}", "doc_id": "test123"}',
+                         response.body)
