@@ -23,7 +23,9 @@ if sys.version_info > (2, 7):
 else:
     from unittest2 import TestCase
 
-from mock import patch
+import mock
+import pytest
+
 from schematics.models import Model
 from schematics.types import StringType
 from tornado.ioloop import IOLoop
@@ -44,15 +46,28 @@ class MyHandler(s.RequestHandler):
 
     @s.async
     def get(self):
+        self.logger.info('Holy moly')
+        self.logger.info('That worked')
         raise s.Return(SimpleModel(msg='Holy moly'))
 
     @s.async
     def post(self, doc_id, model=None):
+        self.logger.info('Holy moly')
+        raise s.Return(SimpleModel(msg='Holy moly'))
         assert isinstance(self.environment, Environment)
         assert isinstance(self.config, tornado.options.options)
         raise s.OkCreated({'docid': 123})
 
 
+@s.provides(s.MediaType.ApplicationJson, default=True)
+class MyHandlerThrowingExceptions(s.RequestHandler):
+
+    @s.async
+    def get(self):
+        self.logger.info('Starting request with unhandled exception')
+        raise Exception()
+
+
 class MyService(s.Service):
 
     def bootstrap(self):
@@ -61,10 +76,16 @@ class MyService(s.Service):
     def run(self):
         self.environment.add_handler('/test', MyHandler, {})
         self.environment.add_handler('/test/(\d+)', MyHandler, {})
+        self.environment.add_handler('/exception', MyHandlerThrowingExceptions,
+                                     {})
 
 
 class ServiceTest(TestCase):
 
+    @pytest.fixture(autouse=True)
+    def empty_commandline(self, monkeypatch):
+        monkeypatch.setattr(sys, 'argv', [])
+
     def test_environment_creation(self):
         service = s.Service()
         env = service.environment
@@ -87,7 +108,7 @@ class ServiceTest(TestCase):
 
         service.initialize_logging()
 
-    @patch('tornado.ioloop.IOLoop.instance')
+    @mock.patch('tornado.ioloop.IOLoop.instance')
     def test_main_method(self, ioloop_instance_mock):
         service = MyService()
         service.main()
@@ -97,14 +118,23 @@ class ServiceTest(TestCase):
 
 class ApplicationIntegrationTest(AsyncHTTPTestCase):
 
+    @pytest.fixture(autouse=True)
+    def empty_commandline(self, monkeypatch):
+        monkeypatch.setattr(sys, 'argv', [])
+
     def get_new_ioloop(self):
         return IOLoop.instance()
 
     def get_app(self):
         service = MyService()
+        service.initialize_logging()
         return service.get_app()
 
     def test_simple_get(self):
         response = self.fetch('/test', headers={'Accept': s.MediaType.ApplicationJson})
         self.assertEqual(200, response.code)
         self.assertEqual('{"msg": "Holy moly"}', response.body)
+
+    def test_get_with_exception(self):
+        response = self.fetch('/exception')
+        self.assertEqual(500, response.code)
